<?php
/* 
    名稱: HiAir API client端範例程式
    撰寫者: HiNet - HiAir , mike huang
    日期: 2022/06/27
*/

// ===== 設定 API Endpoint =====
// 智慧簡訊
$url_sendSMS = 'https://api.sms.hinet.net/api/sendSMS/v1';
// 短簡訊
$url_sendShortSMS = 'https://api.sms.hinet.net/api/sendShortSMS/v1';
// 長簡訊
$url_sendLongSMS = 'https://api.sms.hinet.net/api/sendLongSMS/v1';
// 查詢簡訊
$url_querySMS = 'https://api.sms.hinet.net/api/querySMS/v1';
// 取消預約簡訊
$url_cancelSMS = 'https://api.sms.hinet.net/api/cancelSMS/v1';


// ===== 設定 請求欄位 =====
$data_base = array(
    "username" => "請填入帳號",
    "password" => "請填入密碼",
);
// --- 發送簡訊 ---
// ex:
// {
// "username": "帳號",
// "password": "密碼",
// "mobile": "門號",
// "message": "簡訊內容",
// "limit_time": 1440,
// "order_time": "220201103000"
// }
$data_send_base = array_merge($data_base, array(
    "mobile" => "請填入收訊手機號碼",
    "message" => "請填入簡訊內容",
));
// 簡訊發送 - 一般
$data_send_type_01 = $data_send_base;
// 簡訊發送 - 設定 limit_time
$data_send_type_02 = array_merge($data_send_base, array(
    "limit_time" => 1440,  // 1~1440，單位：分鐘。 (有效範圍外之數值，將預設為 1440 分鐘)
));
// 簡訊發送 - 設定 order_time
$data_send_type_03 = array_merge($data_send_base, array(
    "order_time" => "220627091500",  // 格式為 yyMMddHHmmss，yy：不含世紀之西元年，例如 2022 年請輸入 22。
));
// 簡訊發送 - 設定 limit_time, order_time
$data_send_type_04 = array_merge($data_send_base, array(
    "limit_time" => 1440,
    "order_time" => "220627091500",
));

// --- 查詢簡訊、取消預約簡訊 ---
// ex:
// {
// "username": "帳號",
// "password": "密碼",
// "message_id": "簡訊 ID",
// "msg_type": 2
// }
// 不指定簡訊類型
$data_query_cancel_type_01 = array_merge($data_base, array(
    "message_id" => "請填入簡訊ID",  // ex: A8784619060309156XXX
));
// 指定簡訊類型
$data_query_cancel_type_02 = array_merge($data_base, array(
    "message_id" => "請填入簡訊ID",  // ex: A8784619060309156XXX
    "msg_type" => 2,  // 2:查詢/取消短簡訊 or 12:查詢/取消長簡訊
));


// ===== 指定 請求欄位 =====
// --- 發送簡訊 ---
$url = $url_sendSMS;
// $url = $url_sendShortSMS;
// $url = $url_sendLongSMS;
$data = $data_send_type_01;
// $data = $data_send_type_02;
// $data = $data_send_type_03;
// $data = $data_send_type_04;

// --- 查詢簡訊、取消預約簡訊 ---
// $url = $url_querySMS;
// $url = $url_cancelSMS;
// $data = $data_query_cancel_type_01;
// $data = $data_query_cancel_type_02;


// ===== 發送請求 =====
// 初始化 curl
$request = curl_init();
// 設定 curl
$timeout = 60;
curl_setopt($request, CURLOPT_URL, $url);
curl_setopt($request, CURLOPT_POST, true);  // 若以 POST 發送 request 需設為 true。
curl_setopt($request, CURLOPT_POSTFIELDS, json_encode($data));
curl_setopt($request, CURLOPT_RETURNTRANSFER, true);  // 設為 true，curl 就只會將結果傳回，不會輸出在畫面上。
curl_setopt($request, CURLOPT_CONNECTTIMEOUT, $timeout);  // request timeout 設定60秒
// 設定 Header
$header = array(
    'Content-Type: application/json; charset=UTF-8',
);
curl_setopt($request, CURLOPT_HTTPHEADER, $header);

// 發送請求並轉換回傳結果
$result = json_decode(curl_exec($request), true);
// 取得 http status code
$http_code = curl_getinfo($request, CURLINFO_HTTP_CODE);
// 關閉 curl
curl_close($request);

// --- 處理回傳結果 ---
var_dump($http_code);
var_dump($result);

if ($http_code == 200) {
    // --- 請求成功 ---
    if (is_array($result) && array_key_exists("ret_code", $result) && array_key_exists("ret_content", $result)) {
        echo "ret_code=".$result["ret_code"]."<br>\n";
        echo "ret_content=".$result["ret_content"]."<br>\n";
    } else {
        var_dump($result);
    }
} else {
    // --- catch error ---
    if (is_array($result) && array_key_exists("ret_code", $result) && array_key_exists("ret_content", $result)) {
        echo "ret_code=".$result["ret_code"]."<br>\n";
        echo "ret_content=".$result["ret_content"]."<br>\n";
    } else {
        var_dump($result);
    }
}

// --- 回傳結果範例 ---
// ex: 發送短簡訊
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(0)
//     ["ret_content"]=>
//     string(20) "A8784619060309156XXX"
//     ["msg_type"]=>
//     int(2)
// }
// ret_code=0<br>
// ret_content=A8784619060309156XXX<br>

// ex: 發送長簡訊
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(0)
//     ["ret_content"]=>
//     string(20) "A8784619060309156XXX"
//     ["msg_type"]=>
//     int(12)
// }
// ret_code=0<br>
// ret_content=A8784619060309156XXX<br>

// ex: 查詢簡訊狀態
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(0)
//     ["ret_content"]=>
//     string(25) "Successful:20220629183203"
//     ["msg_type"]=>
//     int(2)
// }
// ret_code=0<br>
// ret_content=Successful:20220629183203<br>

// ex: 查詢簡訊 - 預約簡訊狀態
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(20)
//     ["ret_content"]=>
//     string(29) "reserve message, waiting send"
//     ["msg_type"]=>
//     int(2)
// }
// ret_code=20<br>
// ret_content=reserve message, waiting send<br>

// ex: 查詢簡訊 - message_id錯誤時
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(2)
//     ["ret_content"]=>
//     string(41) "DetailCode:[9] -> System contains no data"
//     ["msg_type"]=>
//     int(12)
// }
// ret_code=2<br>
// ret_content=DetailCode:[9] -> System contains no data<br>

// ex: 查詢簡訊 - 預約簡訊已取消
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(21)
//     ["ret_content"]=>
//     string(31) "reserve Messageage, cancel send"
//     ["msg_type"]=>
//     int(2)
// }
// ret_code=21<br>
// ret_content=reserve Messageage, cancel send<br>

// ex: 取消簡訊
// int(200)
// array(3) {
//     ["ret_code"]=>
//     int(0)
//     ["ret_content"]=>
//     string(10) "Successful"
//     ["msg_type"]=>
//     int(2)
// }
// ret_code=0<br>
// ret_content=Successful<br>

// ex: 帳密錯誤
// int(401)
// array(2) {
//     ["ret_code"]=>
//     int(81)
//     ["ret_content"]=>
//     string(25) "Account or password error"
// }
// ret_code=81<br>
// ret_content=Account or password error<br>

// ex: 欄位格式錯誤
// int(400)
// array(2) {
//     ["ret_code"]=>
//     int(92)
//     ["ret_content"]=>
//     string(36) "Json variable type error: limit_time"
// }
// ret_code=92<br>
// ret_content=Json variable type error: limit_time<br>

// ex: 欄位缺漏
// int(400)
// array(2) {
//     ["ret_code"]=>
//     int(91)
//     ["ret_content"]=>
//     string(22) "Missing field: message"
// }
// ret_code=91<br>
// ret_content=Missing field: message<br>

?>